import acm.program.*;
import acm.util.*;

public class WaveTable extends ConsoleProgram {
	/* Frequencies of the C major scale. */
	private static final double[] FREQUENCIES = {
		261.626,  // C
		293.665,  // D
		329.628,  // E
		349.228,  // F
		391.995,  // G
		440.000,  // A
		493.883   // B
	};
	
	/**
	 * Generates a sample of white noise (random noise).
	 *
	 * @param length The length, in seconds, of the sound to generate.
	 * @return A sound clip of white noise.
	 */
	private double[] whiteNoise(double length) {
		/* Determine how many samples we need. */
		int numSamples = (int)(StdAudio.SAMPLE_RATE * length);
		double[] result = new double[numSamples];
		
		RandomGenerator rgen = RandomGenerator.getInstance();
		for (int i = 0; i < result.length; i++) {
			result[i] = rgen.nextDouble(-1, +1);
		}
		
		return result;
	}
	
	/**
	 * Creates a sine wave (pure tone) of the given frequency and
	 * length.
	 *
	 * @param frequency The frequence (in Hertz) of the sound wave.
	 * @param length The length (in seconds) of that sound wave.
	 * @return A sine wave of the given frequency and length.
	 */
	private double[] sineWave(double frequency, double length) {
		int numSamples = (int)(StdAudio.SAMPLE_RATE * length);
		double[] result = new double[numSamples];
		
		for (int i = 0; i < result.length; i++) {
			result[i] = Math.sin(2.0 * Math.PI * i * (frequency / StdAudio.SAMPLE_RATE));
		}
		
		return result;
	}
	
	public void run() {
		setFont("DejaVuSerif-BOLD-24");

		for (int note = 0; note < FREQUENCIES.length; note++) {
			double[] sound = sineWave(FREQUENCIES[note], 1.0);
			StdAudio.play(sound);
		}
	}
}
